@@ -1,8 +1,23 @@
-\dontrun{
+# Matrix seriation
+# Reproduces Desachy 2004 results
+## Coerce dataset to abundance matrix
+compiegne_count <- as(compiegne, "CountMatrix")
 
+## Get seriation order for columns on EPPM using the reciprocal averaging method
+## Expected column order: N, A, C, K, P, L, B, E, I, M, D, G, O, J, F, H
+(compiegne_indices <- seriate(compiegne_count, method = "reciprocal",
+                              EPPM = TRUE, margin = 2))
+
+## Permute columns
+compiegne_new <- permute(compiegne_count, compiegne_indices)
+
+## Plot new matrix
+plotBar(compiegne_new, EPPM = FALSE)
+
+\donttest{
 # Refine matrix seriation (this is a long running example)
 # Reproduces Peeples and Schachner 2012 results
-count <- as(zuni, "CountMatrix")
+zuni_count <- as(zuni, "CountMatrix")
 
 ## Samples with convex hull maximum dimension length greater than the cutoff
 ## value will be marked for removal.
@@ -11,24 +26,9 @@ fun <- function(x) { mean(x) + sd(x) }
 
 ## Get indices of samples to be kept
 ## Warning: this may take a few seconds!
-refined <- refine(count, cutoff = fun)
-refined[["keep"]]
+set.seed(123)
+(zuni_refined <- refine(zuni_count, cutoff = fun))
 
-# Matrix seriation
-# Reproduces Desachy 2004 results
-## Coerce dataset to abundance matrix
-count <- as(compiegne, "CountMatrix")
-
-## Plot new matrix
-plotBar(count, EPPM = TRUE)
-
-## Get seriation order for columns on EPPM using the reciprocal averaging method
-## Expected column order: N, A, C, K, P, L, B, E, I, M, D, G, O, J, F, H
-indices <- seriate(count, method = "reciprocal", EPPM = TRUE, margin = 2)
-
-## Permute columns
-new <- permute(count, indices)
-
-## Plot new matrix
-plotBar(new, EPPM = TRUE)
+## Get CA-based seriation order
+(zuni_indices <- seriate(zuni_count, zuni_refined, margin = 1))
 }
